@@ -1,7 +1,8 @@
 package Progressive::Web::Application::Template::Base;
-
 use strict;
 use JSON qw//;
+our $JSON;
+BEGIN { $JSON = JSON->new->utf8->pretty(1)->allow_nonref->allow_blessed; }
 
 sub new {
 	my $self = bless {}, $_[0];
@@ -24,6 +25,10 @@ sub get_data_section {
 
 sub render {
 	my $templates = $_[0]->{data};
+	if ($_[0]->can('required_params')) {
+		exists $_[1]->{$_} or Carp::croak(sprintf 'Required template param not found %s', $_)
+			for $_[0]->required_params();
+	}
 	my $dataReg = join '|', map { quotemeta($_) } keys %{$_[1]};
 	for my $key (keys %{$templates}) {
 		$templates->{$key} =~ s/\{($dataReg)\}/encode_json($_[1]->{$1})/eg;
@@ -33,7 +38,7 @@ sub render {
 }
 
 sub encode_json {
-	my $val = JSON->new->utf8->pretty(1)->allow_nonref->allow_blessed->encode($_[0]);
+	my $val = $JSON->encode($_[0]);
 	chomp($val);
 	return $val;
 }
